<?php
/**
 * User Mail Only Register
 * 
 * @package    UserMailOnlyRegister
 * @subpackage User Mail Only Register Main function
/*  Copyright (c) 2019- Katsushi Kawamori (email : dodesyoswift312@gmail.com)
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; version 2 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

$usermailonlyregister = new UserMailOnlyRegister();

class UserMailOnlyRegister {

	/* ==================================================
	 * Construct
	 * @since	1.00
	 */
	public function __construct() {

		add_filter( 'login_message', array($this, 'login_message') );
		add_filter( 'login_headerurl', array($this, 'custom_login_logo_link_url') );
		add_action( 'login_enqueue_scripts', array($this, 'custom_login_logo') );
		add_action( 'register_form', array($this, 'only_email_register_form') );
		add_filter( 'registration_errors', array($this, 'loginpresss_terms_of_use_auth'), 10, 3 );
		add_action( 'user_register', array($this, 'loginpress_terms_of_use_save') );
		add_filter( 'sanitize_user', array($this, 'sanitize_user_email'), 10, 3 );
		add_filter( 'validate_username', array($this, 'validate_user_email'), 10, 2 );
		add_filter( 'authenticate', array($this, 'email_login'), 20, 3 );

		if ( get_option('usermailonlyregister') ) {
			$umor_settings = get_option('usermailonlyregister');
			if ( array_key_exists( "notify_mail_use", $umor_settings ) && $umor_settings['notify_mail_use'] ) {
				add_filter( 'wp_new_user_notification_email', array($this, 'regist_user_notify_mail'), 10, 3 );
			}
		}
		add_filter( 'wp_mail_from_name', array($this, 'mail_from_sitename') );
		add_filter( 'wp_mail_from', array($this, 'mail_from_admin_email') );

		add_action( 'init', array($this, 'php_block_init') );

	}

	/* ==================================================
	 * Register Button block & short code
	 * 
	 * @since	1.00
	 */
	public function php_block_init() {

		wp_register_script(
			'umor-register-block',
			plugins_url( 'js/umor-register-block.js', dirname(__FILE__) ),
			array( 'wp-blocks', 'wp-element', 'wp-components', 'wp-editor' )
		);

		register_block_type( 'user-mail-only-register/umor-register-block', array(
			'editor_script'   => 'umor-register-block',
			'render_callback' => array($this, 'umorregister_func'),
		) );

		add_shortcode( 'umorregister', array($this, 'umorregister_func') );

	}

	/* ==================================================
	 * Register short code
	 * 
	 * @since	1.00
	 */
	public function umorregister_func( $atts ) {

		if ( get_option('users_can_register') ) {
			// Register
			$register_button = '<input type="button" value="'.__('Register').'" onClick="location.href=&#39;'.wp_login_url().'?action=register'.'&#39;">';
			return $register_button;
		} else {
			if ( !is_null($atts) ) {
				$atts = apply_filters('umor_not_register_message', $atts );
				if ( is_wp_error($atts) ) {
					return $atts;
				} else {
					if ( is_array($atts) ) {
						return __('User registration is currently not allowed.');
					} else {
						return $atts;
					}
				}
			}
		}

	}

	/* ==================================================
	 * Login Message
	 * @return	string	$message
	 * @since	1.00
	 */
	public function login_message() {

		$umor_settings = get_option('usermailonlyregister');
		$message = '<p class="message">'.$umor_settings['login_message'].'</p>';
		return $message;

	}

	/* ==================================================
	 * Login Screen
	 * @param	none
	 * @return	string	$logo_link_url
	 * @since	1.00
	 */
	public function custom_login_logo_link_url() {
		if (current_user_can('administrator')) return;
		$umor_settings = get_option('usermailonlyregister');
		if ( empty($umor_settings['login_logo_link_url']) ) return;
		return $umor_settings['login_logo_link_url'];
	}

	/* ==================================================
	 * Login Screen Icon Link
	 * @since	1.00
	 */
	public function custom_login_logo() {
		if (current_user_can('administrator')) return;
		$umor_settings = get_option('usermailonlyregister');
		if ( empty($umor_settings['login_logo_url']) ) return;
		?>
		<style>
		.login #login h1 a {
			width: 150px;
			height: 150px;
			background: url(<?php echo $umor_settings['login_logo_url']; ?>) no-repeat 0 0;
		}
		</style>
		<?php
	}

	/* ==================================================
	 * Only E-mail register form
	 * 
	 * @since	1.00
	 */
	public function only_email_register_form() {
		?><style>#registerform > p:first-child{display:none;}</style>
		<p>
		<input type="checkbox" name="lp_terms_of_use" id="lp_terms_of_use" class="checkbox" />
		<?php
		$umor_settings = get_option('usermailonlyregister');
		$termsofuse_link = '<a href ="'.$umor_settings['termofuse'].'">'.__('terms of use', 'user-mail-only-register').'</a>';
		$message = sprintf(__('Agree the %1$s.', 'user-mail-only-register'), $termsofuse_link);
		echo $message;
		?>
		</p>
		<br />
		<?php
	}

	/* ==================================================
	 * Terms of use for register form
	 * 
	 * @since	1.00
	 */
	public function loginpresss_terms_of_use_auth( $errors, $sanitized_user_login, $user_email ) {

		if ( ! isset( $_POST['lp_terms_of_use'] ) ) {
	    	$errors->add( 'terms_of_use_error', __('Please accept the terms of use.', 'user-mail-only-register') );
			return $errors;
		}

		return $errors;

	}

	/* ==================================================
	 * Terms of use save user meta data
	 * 
	 * @since	1.00
	 */
	public function loginpress_terms_of_use_save( $user_id ) {

		if ( isset( $_POST['lp_terms_of_use'] ) ) {
			update_user_meta( $user_id, 'lp_terms_of_use', $_POST['lp_terms_of_use'] );
		}

	}

	/* ==================================================
	 * Sanitize Email for only E-mail register
	 * 
	 * @since	1.00
	 */
	public function sanitize_user_email( $sanitized_user, $raw_user, $strict ) {

		if ( $raw_user != '' ) {
			return $sanitized_user;
		}

		if ( ! empty ( $_REQUEST['action'] ) && $_REQUEST['action'] === 'register' && is_email( $_POST['user_email'] ) ) {
			return $_POST['user_email'];
		}

		return $sanitized_user;

	}

	/* ==================================================
	 * Validate Email for only E-mail register
	 * 
	 * @since	1.00
	 */
	public function validate_user_email( $valid, $username ) {

		if ( $valid ) {
			return $valid;
		}

		if ( ! empty ( $_REQUEST['action'] ) && $_REQUEST['action'] === 'register' && is_email( $_POST['user_email'] ) ) {
			return true;
		}

		return is_email( $username );

	}

	/* ==================================================
	 * Login Email auth
	 * 
	 * @since	1.00
	 */
	public function email_login( $user, $username, $password ) {

		$user = get_user_by('email',$username);

		if(!empty($user->user_login)) {
			$username = $user->user_login;
		}

		return wp_authenticate_username_password( null, $username, $password );

	}

	/* ==================================================
	 * Register email name
	 * 
	 * @since	1.00
	 */
	public function mail_from_sitename( $from_name ) {
		return get_option( 'blogname' );
	}

	/* ==================================================
	 * Register email address
	 * 
	 * @since	1.00
	 */
	public function mail_from_admin_email( $from_email ) {
		return get_option( 'admin_email' );
	}

	/* ==================================================
	 * Notice mail when newly registering users
	 * 
	 * @since	1.00
	 */
	public function regist_user_notify_mail( $wp_mail, $user, $blogname ) {

		$unm = $user->user_login;
		$key = get_password_reset_key($user);

		$title = sprintf( __('[%s] login Username', 'user-mail-only-register'), $blogname );
		$message = __("Thank you for registering. The login information is as follows.", 'user-mail-only-register')."\r\n\r\n";
		$message .= __('Login Address (URL)').':'.wp_login_url()."\r\n\r\n";
		$message .= sprintf( __('Username').'&'.__('Email').': %s', $unm )."\n";
		$message .= __('To reset your password, visit the following address:').': <'.network_site_url( "wp-login.php?action=rp&key=$key&login=" . rawurlencode( $unm ), 'login' ) . ">\r\n\r\n";

		$wp_mail['subject'] = $title;
		$umor_settings = get_option('usermailonlyregister');
		$wp_mail['message'] = $umor_settings['before']."\r\n\r\n".$message.$umor_settings['after'];

		return $wp_mail;

	}

}

?>
