<?php
/**
 * User Mail Only Register
 * 
 * @package    User Mail Only Register
 * @subpackage UserMailOnlyRegisterAdmin Management screen
    Copyright (c) 2019- Katsushi Kawamori (email : dodesyoswift312@gmail.com)
    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; version 2 of the License.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/

$usermailonlyregisteradmin = new UserMailOnlyRegisterAdmin();

class UserMailOnlyRegisterAdmin {

	/* ==================================================
	 * Construct
	 * @since	1.00
	 */
	public function __construct() {

		add_action( 'admin_menu', array($this, 'plugin_menu'));
		add_action( 'admin_enqueue_scripts', array($this, 'load_custom_wp_admin_style') );
		add_filter( 'plugin_action_links', array($this, 'settings_link'), 10, 2 );

	}

	/* ==================================================
	 * Add a "Settings" link to the plugins page
	 * @since	1.00
	 */
	public function settings_link( $links, $file ) {
		static $this_plugin;
		if ( empty($this_plugin) ) {
			$this_plugin = 'user-mail-only-register/usermailonlyregister.php';
		}
		if ( $file == $this_plugin ) {
			$links[] = '<a href="'.admin_url('options-general.php?page=usermailonlyregister').'">'.__( 'Settings').'</a>';
		}
			return $links;
	}

	/* ==================================================
	 * Settings page
	 * @since	1.00
	 */
	public function plugin_menu() {
		add_options_page( 'User Mail Only Register Options', 'User Mail Only Register', 'manage_options', 'usermailonlyregister', array($this, 'plugin_options') );
	}

	/* ==================================================
	 * Add Css and Script
	 * @since	1.00
	 */
	public function load_custom_wp_admin_style() {
		if ($this->is_my_plugin_screen()) {
			wp_enqueue_style( 'jquery-responsiveTabs', plugin_dir_url( __DIR__ ).'css/responsive-tabs.css' );
			wp_enqueue_style( 'jquery-responsiveTabs-style', plugin_dir_url( __DIR__ ).'css/style.css' );
			wp_enqueue_script('jquery');
			wp_enqueue_script( 'jquery-responsiveTabs', plugin_dir_url( __DIR__ ).'js/jquery.responsiveTabs.min.js' );
			wp_enqueue_script( 'usermailonlyregister-admin-js', plugin_dir_url( __DIR__ ).'js/jquery.usermailonlyregister.admin.js', array('jquery') );
		}
	}

	/* ==================================================
	 * For only admin style
	 * @since	1.00
	 */
	private function is_my_plugin_screen() {
		$screen = get_current_screen();
		if (is_object($screen) && $screen->id == 'settings_page_usermailonlyregister') {
			return TRUE;
		} else {
			return FALSE;
		}
	}

	/* ==================================================
	 * Settings page
	 * @since	1.00
	 */
	public function plugin_options() {

		if ( !current_user_can( 'manage_options' ) )  {
			wp_die( __( 'You do not have sufficient permissions to access this page.' ) );
		}

		if ( isset($_POST['Manageset']) && $_POST['Manageset'] ) {
			if ( check_admin_referer('umor_set', 'usermailonlyregister_set') ) {
				$this->options_updated();
			}
		}

		$scriptname = admin_url('options-general.php?page=usermailonlyregister');
		$usermailonlyregister_settings = get_option('usermailonlyregister');

		?>

		<div class="wrap">
		<h2>User Mail Only Register</h2>

	<div id="usermailonlyregister-admin-tabs">
	  <ul>
		<li><a href="#usermailonlyregister-admin-tabs-1">User Mail Only Register&nbsp<?php _e('Settings'); ?></a></li>
		<li><a href="#usermailonlyregister-admin-tabs-2"><?php _e('Hook', 'user-mail-only-register'); ?></a></li>
		<li><a href="#usermailonlyregister-admin-tabs-3"><?php _e('Donate to this plugin &#187;'); ?></a></li>
	  </ul>

	  <div id="usermailonlyregister-admin-tabs-1">
		<div class="wrap">
			<h2>User Mail Only Register <?php _e('Settings'); ?></h2>	

			<form method="post" action="<?php echo $scriptname; ?>">
			<?php wp_nonce_field('umor_set', 'usermailonlyregister_set'); ?>

			<div style="margin: 5px; padding: 5px;">
			<h3><?php echo 'WordPress '.__('Settings'); ?></h3>
			<div style="display: block;padding:5px 5px">
			<?php _e('Membership'); ?> : 
			<input name="users_can_register" type="checkbox" value="1" <?php checked( '1', get_option('users_can_register') ); ?> />
			<?php _e('Anyone can register'); ?>
			</div>
			<div style="display: block;padding:5px 5px">
			<?php _e('New User Default Role'); ?> : 
			<select name="default_role">
			<?php wp_dropdown_roles( get_option('default_role') ); ?>
			</select>
			</div>
			</div>

			<div style="margin: 5px; padding: 5px;">
			<h3><?php _e('Login screen', 'user-mail-only-register'); ?></h3>
			<div style="display: block;padding:5px 5px"><?php _e('Login message', 'user-mail-only-register'); ?> : <input type="text" name="login_message" style="width: 500px;" value="<?php echo $usermailonlyregister_settings['login_message']; ?>"></div>
			<div style="display: block;padding:5px 5px"><?php _e('login logo URL', 'user-mail-only-register'); ?> : <input type="text" name="login_logo_url" style="width: 500px;" value="<?php echo $usermailonlyregister_settings['login_logo_url']; ?>"></div>
			<div style="display: block;padding:5px 5px"><?php _e('login logo link URL', 'user-mail-only-register'); ?> : <input type="text" name="login_logo_link_url" style="width: 500px;" value="<?php echo $usermailonlyregister_settings['login_logo_link_url']; ?>"></div>
			<div style="display: block;padding:5px 5px"><?php _e('Term of use URL', 'user-mail-only-register'); ?> : <input type="text" name="termofuse" style="width: 500px;" value="<?php echo $usermailonlyregister_settings['termofuse']; ?>"></div>
			</div>

			<div style="margin: 5px; padding: 5px;">
			<h3><?php _e('E-mail notification', 'user-mail-only-register'); ?></h3>
			<div style="display: block;padding:5px 5px">
			<div><?php _e('Before login information (Text Only)', 'user-mail-only-register'); ?></div>
			<textarea name="umor_before" style="resize: auto; max-width: 500px; max-height: 500px; min-width: 100px; min-height: 100px; width:500px; height:100px"><?php echo $usermailonlyregister_settings['before']; ?></textarea>
			</div>
			<div style="display: block;padding:5px 5px">
			<div><?php _e('After login information (Text Only)', 'user-mail-only-register'); ?></div>
			<textarea name="umor_after" style="resize: auto; max-width: 500px; max-height: 500px; min-width: 100px; min-height: 100px; width:500px; height:100px"><?php echo $usermailonlyregister_settings['after']; ?></textarea>
			</div>
			<?php
			$filter_link = '<a style="text-decoration: none;" href="'.__('https://developer.wordpress.org/reference/hooks/wp_new_user_notification_email/', 'user-mail-only-register').'" target="_blank">wp_new_user_notification_email</a>';
			?>
			<div style="display: block;padding:5px 5px">
			<div><input type="checkbox" name="notify_mail" value="1" <?php checked( '1', $usermailonlyregister_settings['notify_mail_use'] ); ?>>
			<?php _e('Use this plugin email notification', 'user-mail-only-register'); ?>
			</div>
				<div style="display: block;padding:5px 15px">
				<?php echo sprintf(__('This plugin will notify the registrant of the mail using the filter hook %1$s. Please uncheck this if you want to your own notify mail using filter hook %1$s.', 'user-mail-only-register'), $filter_link); ?>
				</div>
			</div>
			</div>

			<?php submit_button( __('Save Changes'), 'large', 'Manageset', FALSE ); ?>

			</form>

		</div>
	  </div>

	  <div id="usermailonlyregister-admin-tabs-2">
		<div class="wrap">
			<h3><?php _e('The following filter hook are provided.', 'user-mail-only-register'); ?></h3>
			<h4>umor_not_register_message</h4>
			<div><?php _e('Message when registration is impossible.', 'user-mail-only-register'); ?></div>
			<p>
			<div><strong><?php _e('Sample code', 'user-mail-only-register'); ?></strong></div>
<textarea rows="8" cols="60" readonly>
// Filter hook
add_filter('umor_not_register_message', 'not_register' );
// Function
public function not_register() {
   	// Please write the process.
	return 'It is busy. Please use another server.';
}
</textarea>
		</div>
	  </div>

	  <div id="usermailonlyregister-admin-tabs-3">
		<div class="wrap">
		<?php $this->credit(); ?>
		</div>
	  </div>

	</div>

		</div>
		<?php
	}

	/* ==================================================
	 * Credit
	 */
	private function credit() {

		$plugin_name = NULL;
		$plugin_ver_num = NULL;
		$plugin_path = plugin_dir_path( __DIR__ );
		$plugin_dir = untrailingslashit($plugin_path);
		$slugs = explode('/', $plugin_dir);
		$slug = end($slugs);
		$files = scandir($plugin_dir);
		foreach ($files as $file) {
			if($file == '.' || $file == '..' || is_dir($plugin_path.$file)){
				continue;
			} else {
				$exts = explode('.', $file);
				$ext = strtolower(end($exts));
				if ( $ext === 'php' ) {
					$plugin_datas = get_file_data( $plugin_path.$file, array('name'=>'Plugin Name', 'version' => 'Version') );
					if ( array_key_exists( "name", $plugin_datas ) && !empty($plugin_datas['name']) && array_key_exists( "version", $plugin_datas ) && !empty($plugin_datas['version']) ) {
						$plugin_name = $plugin_datas['name'];
						$plugin_ver_num = $plugin_datas['version'];
						break;
					}
				}
			}
		}
		$plugin_version = __('Version:').' '.$plugin_ver_num;
		$faq = __('https://wordpress.org/plugins/'.$slug.'/faq', $slug);
		$support = 'https://wordpress.org/support/plugin/'.$slug;
		$review = 'https://wordpress.org/support/view/plugin-reviews/'.$slug;
		$translate = 'https://translate.wordpress.org/projects/wp-plugins/'.$slug;
		$facebook = 'https://www.facebook.com/katsushikawamori/';
		$twitter = 'https://twitter.com/dodesyo312';
		$youtube = 'https://www.youtube.com/channel/UC5zTLeyROkvZm86OgNRcb_w';
		$donate = __('https://shop.riverforest-wp.info/donate/', $slug);

		?>
		<span style="font-weight: bold;">
		<div>
		<?php echo $plugin_version; ?> | 
		<a style="text-decoration: none;" href="<?php echo $faq; ?>" target="_blank"><?php _e('FAQ'); ?></a> | <a style="text-decoration: none;" href="<?php echo $support; ?>" target="_blank"><?php _e('Support Forums'); ?></a> | <a style="text-decoration: none;" href="<?php echo $review; ?>" target="_blank"><?php _e('Reviews', 'user-mail-only-register'); ?></a>
		</div>
		<div>
		<a style="text-decoration: none;" href="<?php echo $translate; ?>" target="_blank"><?php echo sprintf(__('Translations for %s'), $plugin_name); ?></a> | <a style="text-decoration: none;" href="<?php echo $facebook; ?>" target="_blank"><span class="dashicons dashicons-facebook"></span></a> | <a style="text-decoration: none;" href="<?php echo $twitter; ?>" target="_blank"><span class="dashicons dashicons-twitter"></span></a> | <a style="text-decoration: none;" href="<?php echo $youtube; ?>" target="_blank"><span class="dashicons dashicons-video-alt3"></span></a>
		</div>
		</span>

		<div style="width: 250px; height: 180px; margin: 5px; padding: 5px; border: #CCC 2px solid;">
		<h3><?php _e('Please make a donation if you like my work or would like to further the development of this plugin.', $slug); ?></h3>
		<div style="text-align: right; margin: 5px; padding: 5px;"><span style="padding: 3px; color: #ffffff; background-color: #008000">Plugin Author</span> <span style="font-weight: bold;">Katsushi Kawamori</span></div>
		<button type="button" style="margin: 5px; padding: 5px;" onclick="window.open('<?php echo $donate; ?>')"><?php _e('Donate to this plugin &#187;'); ?></button>
		</div>

		<?php

	}

	/* ==================================================
	 * Update wp_options table.
	 * @param	none
	 * @since	1.00
	 */
	private function options_updated(){

		if ( !empty($_POST['Manageset']) ) {
			if ( !empty($_POST['users_can_register']) ) {
				update_option('users_can_register', TRUE);
			} else {
				update_option('users_can_register', FALSE);
			}
			if ( !empty($_POST['default_role']) ) {
				update_option('default_role', sanitize_text_field($_POST['default_role']));
			}
			$usermailonlyregister_settings = get_option('usermailonlyregister');
			if ( !empty($_POST['login_message']) ) {
				$usermailonlyregister_settings['login_message'] = sanitize_text_field($_POST['login_message']);
			}
			$usermailonlyregister_settings['login_logo_url'] = esc_url($_POST['login_logo_url']);
			if ( !empty($_POST['login_logo_link_url']) ) {
				$usermailonlyregister_settings['login_logo_link_url'] = esc_url($_POST['login_logo_link_url']);
			}
			if ( !empty($_POST['termofuse']) ) {
				$usermailonlyregister_settings['termofuse'] = esc_url($_POST['termofuse']);
			}
			$usermailonlyregister_settings['before'] = sanitize_text_field($_POST['umor_before']);
			$usermailonlyregister_settings['after'] = sanitize_text_field($_POST['umor_after']);
			if ( !empty($_POST['notify_mail']) ) {
				$usermailonlyregister_settings['notify_mail_use'] = intval($_POST['notify_mail']);
			} else {
				$usermailonlyregister_settings['notify_mail_use'] = FALSE;
			}
			update_option( 'usermailonlyregister', $usermailonlyregister_settings );
		}
		echo '<div class="notice notice-success is-dismissible"><ul><li>'.__('Settings').' --> '.__('Settings saved.').'</li></ul></div>';

	}

}

?>